@@ -1,6 +1,4 @@
-##########################################################################################
-# config
-##########################################################################################
+"""Show the current configuration"""
 # pragma: no cover
 
 from loguru import logger as log
